.. _plasmapy-communication:

Feedback and Communication
==========================

Matrix chat room
----------------

The primary communication channel for PlasmaPy is our `Matrix chat
room`_  💬. There is also a `Gitter bridge`_ to this chat room.

GitHub Discussions page
-----------------------

PlasmaPy's `GitHub Discussions page`_ is a great place to suggest ideas,
bring up discussion topics, and ask questions in threaded public
discussions.

Mailing list
------------

We also have a low traffic `mailing list`_ for occasional announcements
and infrequent discussions.

Suggestion box
--------------

We have a `suggestion box`_ if you would like to (optionally
anonymously) suggest a feature/topic for consideration. These will be
reposted as GitHub issues, as appropriate, for further discussion.

Meetings and events
-------------------

Please check `PlasmaPy meetings`_ for regularly scheduled meetings and
special events. The regularly scheduled meetings include a community
meeting to discuss code development, a project meeting to discuss
broader aspects of the PlasmaPy project like education and outreach to
the broader plasma community, and meetings of PlasmaPy working groups.
The special events include |Plasma Hack Week|.

.. _GitHub Discussions page: https://github.com/PlasmaPy/PlasmaPy/discussions
.. _Gitter bridge: https://app.gitter.im/#/room/#PlasmaPy_Lobby:gitter.im
.. _mailing list: https://groups.google.com/forum/#!forum/plasmapy
.. _PlasmaPy meetings: https://www.plasmapy.org/meetings
.. _suggestion box: https://docs.google.com/forms/d/e/1FAIpQLSdT3O5iHZrLJRuavFyzoR23PGy0Prfzx2SQOcwJGWtvHyT2lw/viewform?usp=sf_link
